#######
Credits
#######

=================
Corporate Sponsor
=================

- `HotOffThe Hamster <https://github.com/hotoffthehamster>`__

================
Human Maintainer
================

- `Landon Bouma <https://github.com/landonb>`__
  ``<hotoffthehamster+landonb -at- gmail.com>``

